@@ -34,7 +34,7 @@ from .options import DjangoMutationOptions, DjangoNodeOptions
 from .permissions import AllowAny, BasePermission, restricted_field
 from .settings import gdx_settings
 from .typing import Fields, Sequence
-from .utils import get_filters_from_info
+from .utils import add_translatable_fields, get_filters_from_info
 
 if TYPE_CHECKING:
     from django.db import models
@@ -150,6 +150,9 @@ class DjangoNode(DjangoObjectType):
             msg = f"`Meta.fields` is should be a Sequence of field names or `{ALL_FIELDS}`, received: `{fields}`."
             raise TypeError(msg)
 
+        if fields != ALL_FIELDS:
+            fields = add_translatable_fields(model, fields)
+
         if not hasattr(cls, "pk") and (fields == ALL_FIELDS or "pk" in fields):
             cls._add_pk_field(model)
 
@@ -257,7 +260,7 @@ class DjangoMutation(ClientIDMutation):
 
     - Can add permission checks via permission classes.
 
-    - TODO: Formats errors raised from nested serializers to a compatible form.
+    - Converts raise serializer validation errors to GraphQL validation errors.
 
     ---
 
